@@ -17,7 +17,7 @@ pytest.importorskip("fastparquet")
 import numpy as np
 import pandas as pd
 
-from dask.dataframe._compat import PANDAS_GT_150, PANDAS_GT_200
+from dask.dataframe._compat import PANDAS_GE_150, PANDAS_GE_200
 from dask.dataframe.utils import assert_eq
 
 pytestmark = [
@@ -26,16 +26,30 @@ pytestmark = [
         reason="Unnecessary, and hard to get spark working on non-linux platforms",
     ),
     pytest.mark.skipif(
-        PANDAS_GT_200,
+        PANDAS_GE_200,
         reason="pyspark doesn't yet have support for pandas 2.0",
     ),
     # we only test with pyarrow strings and pandas 2.0
     pytest.mark.skip_with_pyarrow_strings,  # pyspark doesn't support pandas 2.0
 ]
 
+
+@pytest.fixture(
+    params=[
+        "pyarrow",
+        pytest.param(
+            "fastparquet", marks=pytest.mark.filterwarnings("ignore::FutureWarning")
+        ),
+    ]
+)
+def engine(request):
+    pytest.importorskip(request.param)
+    return request.param
+
+
 # pyspark auto-converts timezones -- round-tripping timestamps is easier if
 # we set everything to UTC.
-pdf = timeseries(freq="1H").compute()
+pdf = timeseries(freq="1h").compute()
 pdf.index = pdf.index.tz_localize("UTC")
 pdf = pdf.reset_index()
 
@@ -62,8 +76,7 @@ def spark_session():
         signal.signal(signal.SIGINT, prev)
 
 
-@pytest.mark.parametrize("npartitions", (1, 5, 10))
-@pytest.mark.parametrize("engine", ("pyarrow", "fastparquet"))
+@pytest.mark.parametrize("npartitions", [1, 5, 10])
 def test_roundtrip_parquet_spark_to_dask(spark_session, npartitions, tmpdir, engine):
     tmpdir = str(tmpdir)
 
@@ -80,7 +93,6 @@ def test_roundtrip_parquet_spark_to_dask(spark_session, npartitions, tmpdir, eng
     assert_eq(ddf, pdf, check_index=False)
 
 
-@pytest.mark.parametrize("engine", ("pyarrow", "fastparquet"))
 def test_roundtrip_hive_parquet_spark_to_dask(spark_session, tmpdir, engine):
     tmpdir = str(tmpdir)
 
@@ -103,8 +115,7 @@ def test_roundtrip_hive_parquet_spark_to_dask(spark_session, tmpdir, engine):
     assert_eq(ddf, pdf.sort_index(axis=1), check_index=False)
 
 
-@pytest.mark.parametrize("npartitions", (1, 5, 10))
-@pytest.mark.parametrize("engine", ("pyarrow", "fastparquet"))
+@pytest.mark.parametrize("npartitions", [1, 5, 10])
 def test_roundtrip_parquet_dask_to_spark(spark_session, npartitions, tmpdir, engine):
     tmpdir = str(tmpdir)
     ddf = dd.from_pandas(pdf, npartitions=npartitions)
@@ -163,7 +174,7 @@ def test_roundtrip_parquet_spark_to_dask_extension_dtypes(spark_session, tmpdir)
     assert_eq(ddf, pdf, check_index=False)
 
 
-@pytest.mark.skipif(not PANDAS_GT_150, reason="Requires pyarrow-backed nullable dtypes")
+@pytest.mark.skipif(not PANDAS_GE_150, reason="Requires pyarrow-backed nullable dtypes")
 def test_read_decimal_dtype_pyarrow(spark_session, tmpdir):
     tmpdir = str(tmpdir)
     npartitions = 3
